==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridHeaderTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeaderTypeDescriptionMetadata } from "./WebHeaderTypeDescriptionMetadata";
import { WebGridHeaderTemplateContextDescription } from "./WebGridHeaderTemplateContextDescription";
/**
 * @hidden
 */
var WebGridHeaderTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridHeaderTemplateContextDescriptionMetadata, _super);
    function WebGridHeaderTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridHeaderTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridHeaderTemplateContextDescriptionMetadata.a == null) {
            WebGridHeaderTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridHeaderTemplateContextDescriptionMetadata.c(WebGridHeaderTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebGridHeaderTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridHeaderTemplateContextDescriptionMetadata.a);
        WebHeaderTypeDescriptionMetadata.d(a);
    };
    WebGridHeaderTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridHeaderTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "ExportedType:WebHeaderType");
    };
    WebGridHeaderTemplateContextDescriptionMetadata.d = function (a) {
        WebGridHeaderTemplateContextDescriptionMetadata.b(a);
        a.aa("WebGridHeaderTemplateContext", function () { return new WebGridHeaderTemplateContextDescription(); });
        a.z("WebGridHeaderTemplateContext", WebGridHeaderTemplateContextDescriptionMetadata.a);
    };
    WebGridHeaderTemplateContextDescriptionMetadata.$t = markType(WebGridHeaderTemplateContextDescriptionMetadata, 'WebGridHeaderTemplateContextDescriptionMetadata');
    WebGridHeaderTemplateContextDescriptionMetadata.a = null;
    return WebGridHeaderTemplateContextDescriptionMetadata;
}(Base));
export { WebGridHeaderTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridHeaderTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeaderTypeDescriptionMetadata } from "./WebHeaderTypeDescriptionMetadata";
import { WebGridHeaderTemplateContextDescription } from "./WebGridHeaderTemplateContextDescription";
/**
 * @hidden
 */
var WebGridHeaderTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridHeaderTemplateContextDescriptionMetadata, _super);
    function WebGridHeaderTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridHeaderTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridHeaderTemplateContextDescriptionMetadata.a == null) {
            WebGridHeaderTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridHeaderTemplateContextDescriptionMetadata.c(WebGridHeaderTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridHeaderTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridHeaderTemplateContextDescriptionMetadata.a);
        WebHeaderTypeDescriptionMetadata.d(a);
    };
    WebGridHeaderTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridHeaderTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebHeaderType");
    };
    WebGridHeaderTemplateContextDescriptionMetadata.d = function (a) {
        WebGridHeaderTemplateContextDescriptionMetadata.b(a);
        a.ac("WebGridHeaderTemplateContext", function () { return new WebGridHeaderTemplateContextDescription(); });
        a.ab("WebGridHeaderTemplateContext", WebGridHeaderTemplateContextDescriptionMetadata.a);
    };
    WebGridHeaderTemplateContextDescriptionMetadata.$t = markType(WebGridHeaderTemplateContextDescriptionMetadata, 'WebGridHeaderTemplateContextDescriptionMetadata');
    WebGridHeaderTemplateContextDescriptionMetadata.a = null;
    return WebGridHeaderTemplateContextDescriptionMetadata;
}(Base));
export { WebGridHeaderTemplateContextDescriptionMetadata };
